@@ -3,7 +3,7 @@
 package KiokuDB;
 use Moose;
 
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 
 use constant SERIAL_IDS => not not our $SERIAL_IDS;
 
@@ -13,6 +13,7 @@ use KiokuDB::Collapser;
 use KiokuDB::Linker;
 use KiokuDB::LiveObjects;
 use KiokuDB::TypeMap;
+use KiokuDB::TypeMap::Shadow;
 use KiokuDB::TypeMap::Resolver;
 
 use Hash::Util::FieldHash::Compat qw(idhash);
@@ -27,8 +28,8 @@ sub connect {
 }
 
 has typemap => (
-    isa => "KiokuDB::TypeMap",
-    is  => "ro",
+    does => "KiokuDB::Role::TypeMap",
+    is   => "ro",
     lazy_build => 1,
 );
 
@@ -36,6 +37,27 @@ sub _build_typemap {
     KiokuDB::TypeMap->new;
 }
 
+has merged_typemap => (
+    does => "KiokuDB::Role::TypeMap",
+    is   => "ro",
+    lazy_build => 1,
+);
+
+sub _build_merged_typemap {
+    my $self = shift;
+
+    if ( $self->backend->can("default_typemap") ) {
+        return KiokuDB::TypeMap::Shadow->new(
+            typemaps => [
+                $self->typemap,
+                $self->backend->default_typemap,
+            ],
+        );
+    } else {
+        return $self->typemap;
+    }
+}
+
 has typemap_resolver => (
     isa => "KiokuDB::TypeMap::Resolver",
     is  => "ro",
@@ -44,8 +66,9 @@ has typemap_resolver => (
 
 sub _build_typemap_resolver {
     my $self = shift;
+
     KiokuDB::TypeMap::Resolver->new(
-        typemap => $self->typemap,
+        typemap => $self->merged_typemap,
     );
 }
 
