@@ -3,9 +3,6 @@
 package KiokuDB::Backend::Serialize::JSPON::Collapser;
 use Moose;
 
-use Check::ISA;
-use Devel::PartialDump qw(croak);
-
 use KiokuDB::Entry;
 use KiokuDB::Reference;
 
@@ -31,20 +28,18 @@ sub visit_hash_key {
 sub visit_object {
     my ( $self, $object ) = @_;
 
-    if ( obj $object, 'KiokuDB::Reference' ) {
-        return { '$ref' => $object->id, ( $object->is_weak ? ( weak => 1 ) : () ) };
-    } elsif ( obj $object, 'KiokuDB::Entry' ) {
-        croak("Unsupported data for JSPON: ", $object->data) unless ref($object->data) eq 'HASH';
+    if ( ref($object) eq 'KiokuDB::Reference' ) {
+        return { '$ref' => $object->id . ".data", ( $object->is_weak ? ( weak => 1 ) : () ) };
+    } elsif ( ref($object) eq 'KiokuDB::Entry' ) {
         my $id = $object->id;
         return {
             ( $object->has_class ? ( __CLASS__ => $object->class ) : () ),
             ( $id ? ( id => $id ) : () ),
-            $self->visit_hash_entries($object->data),
+            data => $self->visit($object->data),
         };
+    } else {
+        return $object; # we let JSON complain about objects
     }
-
-    #return $object; # FIXME maybe we allow this for objects with hooks? not for now
-    croak "unexpected object ", $object, " in structure";
 }
 
 __PACKAGE__->meta->make_immutable;
