@@ -3,13 +3,11 @@
 package KiokuDB::LiveObjects;
 use Moose;
 
-use MooseX::AttributeHelpers;
-
 use Scalar::Util qw(weaken);
 use Scope::Guard;
 use Hash::Util::FieldHash::Compat qw(fieldhash);
 use Carp qw(croak);
-use Devel::PartialDump qw(croak);
+BEGIN { local $@; eval 'use Devel::PartialDump qw(croak)' };
 use Set::Object;
 
 use KiokuDB::LiveObjects::Scope;
@@ -25,18 +23,31 @@ has _objects => (
 );
 
 has _ids => (
-    metaclass => 'Collection::Hash',
+    #metaclass => 'Collection::Hash',
     isa => "HashRef",
     is  => "ro",
     init_arg => undef,
     default => sub { return {} },
-    provides => {
-        get    => "ids_to_objects",
-        keys   => "live_ids",
-        values => "live_objects",
-    },
+    #provides => {
+    #    get    => "ids_to_objects",
+    #    keys   => "live_ids",
+    #    values => "live_objects",
+    #},
 );
 
+sub ids_to_objects {
+    my ( $self, @ids ) = @_;
+    @{ $self->_ids }{@ids};
+}
+
+sub live_ids {
+    keys %{ shift->_ids };
+}
+
+sub live_objects {
+    values %{ shift->_ids };
+}
+
 has _entry_objects => (
     isa => "HashRef",
     is  => "ro",
@@ -45,18 +56,31 @@ has _entry_objects => (
 );
 
 has _entry_ids => (
-    metaclass => 'Collection::Hash',
+    #metaclass => 'Collection::Hash',
     isa => "HashRef",
     is  => "ro",
     init_arg => undef,
     default  => sub { return {} },
-    provides => {
-        get    => "ids_to_entries",
-        keys   => "loaded_ids",
-        values => "live_entries",
-    },
+    #provides => {
+    #    get    => "ids_to_entries",
+    #    keys   => "loaded_ids",
+    #    values => "live_entries",
+    #},
 );
 
+sub ids_to_entries {
+    my ( $self, @ids ) = @_;
+    @{ $self->_entry_ids }{@ids}
+}
+
+sub loaded_ids {
+    keys %{ shift->_entry_ids };
+}
+
+sub live_entries {
+    values %{ shift->_enty_ids };
+}
+
 has current_scope => (
     isa => "KiokuDB::LiveObjects::Scope",
     is  => "ro",
@@ -254,7 +278,7 @@ sub insert {
 
         croak($object, " is not a reference") unless ref($object);
         croak($object, " is an entry") if blessed($object) && $object->isa("KiokuDB::Entry");
-        croak($object, " is already registered as $o->{$object}{id}") if exists $o->{$object};
+        croak($object, " is already registered as $o->{$object}{id}") if exists $o->{$object} and $o->{$object}{id} ne $id;;
 
         if ( exists $i->{$id} ) {
             croak "An object with the id '$id' is already registered";
